@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Software::License::Artistic_2_0;
 BEGIN {
-  $Software::License::Artistic_2_0::VERSION = '0.101370';
+  $Software::License::Artistic_2_0::VERSION = '0.101410';
 }
 use base 'Software::License';
 # ABSTRACT: The Artistic License 2.0
@@ -10,7 +10,7 @@ use base 'Software::License';
 sub name { 'The Artistic License 2.0' }
 sub url  { 'http://www.perlfoundation.org/artistic_license_2_0' }
 sub meta_name  { 'artistic_2' }
-sub meta2_name { 'artistic_2_0' }
+sub meta2_name { 'artistic_2' }
 
 1;
 
@@ -23,7 +23,7 @@ Software::License::Artistic_2_0 - The Artistic License 2.0
 
 =head1 VERSION
 
-version 0.101370
+version 0.101410
 
 =head1 AUTHOR
 
